==> RTCA_1.4.0.zip: RTCA/doc/aboutRTCA.R <==
###################################################
### chunk number 1: loadLib
###################################################
#line 74 "aboutRTCA.Rnw"
library(RTCA)


###################################################
### chunk number 2: dataImport
###################################################
#line 79 "aboutRTCA.Rnw"
ofile <-  system.file("extdata/testOutput.csv", package="RTCA")
x <- parseRTCA(ofile)


###################################################
### chunk number 3: dataImportFile eval=FALSE
###################################################
## #line 85 "aboutRTCA.Rnw"
## ofile <- file.path("/directory/of/the/file/myFile.txt")


###################################################
### chunk number 4: printRTCA
###################################################
#line 90 "aboutRTCA.Rnw"
x


###################################################
### chunk number 5: annotate
###################################################
#line 103 "aboutRTCA.Rnw"
pfile <- system.file("extdata/testOutputPhenoData.csv", package="RTCA")
pData <- read.csv(pfile, sep="\t", row.names="Well")
metaData <- data.frame(labelDescription=c(
                         "Rack number",
                         "siRNA catalogue number",
                         "siRNA gene symbol",
                         "siRNA EntrezGene ID",
                         "siRNA targeting accession"
                         ))
phData <- new("AnnotatedDataFrame", data=pData, varMetadata=metaData)


###################################################
### chunk number 6: annotateAssign
###################################################
#line 117 "aboutRTCA.Rnw"
phenoData(x) <- phData


###################################################
### chunk number 7: annotatedx
###################################################
#line 121 "aboutRTCA.Rnw"
head(pData(x))


###################################################
### chunk number 8: alternativeAnnotate eval=FALSE
###################################################
## #line 126 "aboutRTCA.Rnw"
## x <- parseRTCA(ofile, phenoData=phData)


###################################################
### chunk number 9: plotRTCA
###################################################
#line 136 "aboutRTCA.Rnw"
  plot(x[,1:4], type="l", col="black", lty=1:4, xlab="time point", ylab="Cell Index")


###################################################
### chunk number 10: addTimeLine
###################################################
#line 151 "aboutRTCA.Rnw"
x <- addAction(x, 22, "trasfection")
x <- addAction(x, 30, "medium change")


###################################################
### chunk number 11: extractTimeLine
###################################################
#line 157 "aboutRTCA.Rnw"
timeline(x)


###################################################
### chunk number 12: timeLineExamples
###################################################
#line 162 "aboutRTCA.Rnw"
tl <- timeline(x)
show(tl)
tlAdd <- addAction(tl, 35, "normalization"); tlAdd
getAction(tl, 22)
tlComp <- updateAction(tl, 22, "compound transfection")
tlComp
tlRm <- rmAction(tlAdd,35 ); tlRm


###################################################
### chunk number 13: ratioTransform
###################################################
#line 179 "aboutRTCA.Rnw"
xRatio <- ratioTransform(x, 35)
plot(xRatio[,1:4], lty=1:4, type="l", col="black",xlab="time point", ylab="Normalized Cell Index")
abline(v=35, col="red", lwd=2)


###################################################
### chunk number 14: plateView
###################################################
#line 200 "aboutRTCA.Rnw"
plateView(x, col="orange")


###################################################
### chunk number 15: sessionInfo
###################################################
#line 214 "aboutRTCA.Rnw"
toLatex(sessionInfo())

==> RTCA_1.63.0.zip: RTCA/doc/aboutRTCA.R <==
### R code from vignette source 'aboutRTCA.Rnw'

###################################################
### code chunk number 1: loadLib
###################################################
library(RTCA)


###################################################
### code chunk number 2: dataImport
###################################################
ofile <-  system.file("extdata/testOutput.csv", package="RTCA")
x <- parseRTCA(ofile)


###################################################
### code chunk number 3: dataImportFile (eval = FALSE)
###################################################
## ofile <- file.path("/directory/of/the/file/myFile.txt")


###################################################
### code chunk number 4: printRTCA
###################################################
x


###################################################
### code chunk number 5: annotate
###################################################
pfile <- system.file("extdata/testOutputPhenoData.csv", package="RTCA")
pData <- read.csv(pfile, sep="\t", row.names="Well")
metaData <- data.frame(labelDescription=c(
                         "Rack number",
                         "siRNA catalogue number",
                         "siRNA gene symbol",
                         "siRNA EntrezGene ID",
                         "siRNA targeting accession"
                         ))
phData <- new("AnnotatedDataFrame", data=pData, varMetadata=metaData)


###################################################
### code chunk number 6: annotateAssign
###################################################
phenoData(x) <- phData


###################################################
### code chunk number 7: annotatedx
###################################################
head(pData(x))


###################################################
### code chunk number 8: alternativeAnnotate (eval = FALSE)
###################################################
## x <- parseRTCA(ofile, phenoData=phData)


###################################################
### code chunk number 9: plotRTCA
###################################################
  plot(x[,1:4], type="l", col="black", lty=1:4, xlab="time point", ylab="Cell Index")


###################################################
### code chunk number 10: addTimeLine
###################################################
x <- addAction(x, 22, "trasfection")
x <- addAction(x, 30, "medium change")


###################################################
### code chunk number 11: extractTimeLine
###################################################
timeline(x)


###################################################
### code chunk number 12: timeLineExamples
###################################################
tl <- timeline(x)
show(tl)
tlAdd <- addAction(tl, 35, "normalization"); tlAdd
getAction(tl, 22)
tlComp <- updateAction(tl, 22, "compound transfection")
tlComp
tlRm <- rmAction(tlAdd,35 ); tlRm


###################################################
### code chunk number 13: ratioTransform
###################################################
xRatio <- ratioTransform(x, 35)
plot(xRatio[,1:4], lty=1:4, type="l", col="black",xlab="time point", ylab="Normalized Cell Index")
abline(v=35, col="red", lwd=2)


###################################################
### code chunk number 14: plateView
###################################################
plateView(x, col="orange")


###################################################
### code chunk number 15: sessionInfo
###################################################
toLatex(sessionInfo())
